@@ -7,15 +7,14 @@ import os
 import pytest
 
 
-@pytest.mark.skipif(not os.path.exists('testresult.txt'),
-                    reason='Only run in CI tests')
+@pytest.mark.skipif(not os.path.exists("testresult.txt"), reason="Only run in CI tests")
 def test_failed_testresult_stacktrace():
-    with open('testresult.txt') as f:
+    with open("testresult.txt") as f:
         contents = f.read()
     # before the fix, a triple question mark has been displayed
     # instead of the stacktrace
     assert contents
-    print('contents', contents)
-    assert '???' not in contents
-    assert 'AttributeError' not in contents
-    assert 'def test_fs(fs):' in contents
+    print("contents", contents)
+    assert "???" not in contents
+    assert "AttributeError" not in contents
+    assert "def test_fs(fs):" in contents
